@@ -109,8 +109,8 @@ impl Default for FnmConfig {
 }
 
 impl FnmConfig {
-    pub fn version_file_strategy(&self) -> &VersionFileStrategy {
-        &self.version_file_strategy
+    pub fn version_file_strategy(&self) -> VersionFileStrategy {
+        self.version_file_strategy
     }
 
     pub fn corepack_enabled(&self) -> bool {
@@ -128,14 +128,13 @@ impl FnmConfig {
         }
     }
 
-    pub fn log_level(&self) -> &LogLevel {
-        &self.log_level
+    pub fn log_level(&self) -> LogLevel {
+        self.log_level
     }
 
     pub fn base_dir_with_default(&self) -> std::path::PathBuf {
-        let user_pref = self.base_dir.clone();
-        if let Some(dir) = user_pref {
-            return dir;
+        if let Some(dir) = &self.base_dir {
+            return dir.clone();
         }
 
         self.directories.default_base_dir()
