@@ -2,7 +2,7 @@ use std::fmt::Display;
 
 use clap::ValueEnum;
 
-#[derive(Debug, Default, PartialEq, PartialOrd, Eq, Ord, Clone, ValueEnum)]
+#[derive(Debug, Default, PartialEq, PartialOrd, Eq, Ord, Clone, Copy, ValueEnum)]
 pub enum LogLevel {
     Quiet,
     Error,
@@ -11,23 +11,21 @@ pub enum LogLevel {
     Info,
 }
 
-impl Display for LogLevel {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl LogLevel {
+    pub fn as_str(self) -> &'static str {
         match self {
-            LogLevel::Quiet => write!(f, "quiet"),
-            LogLevel::Error => write!(f, "error"),
-            LogLevel::Info => write!(f, "info"),
+            Self::Quiet => "quiet",
+            Self::Info => "info",
+            Self::Error => "error",
         }
     }
-}
 
-impl LogLevel {
-    pub fn is_writable(&self, logging: &Self) -> bool {
+    pub fn is_writable(self, logging: Self) -> bool {
         use std::cmp::Ordering;
-        matches!(self.cmp(logging), Ordering::Greater | Ordering::Equal)
+        matches!(self.cmp(&logging), Ordering::Greater | Ordering::Equal)
     }
 
-    pub fn writer_for(&self, logging: &Self) -> Box<dyn std::io::Write> {
+    pub fn writer_for(self, logging: Self) -> Box<dyn std::io::Write> {
         if self.is_writable(logging) {
             match logging {
                 Self::Error => Box::from(std::io::stderr()),
@@ -43,13 +41,9 @@ impl LogLevel {
     }
 }
 
-impl From<LogLevel> for &'static str {
-    fn from(level: LogLevel) -> Self {
-        match level {
-            LogLevel::Quiet => "quiet",
-            LogLevel::Info => "info",
-            LogLevel::Error => "error",
-        }
+impl Display for LogLevel {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_str(self.as_str())
     }
 }
 
@@ -57,7 +51,7 @@ impl From<LogLevel> for &'static str {
 macro_rules! outln {
     ($config:ident, $level:path, $($expr:expr),+) => {{
         use $crate::log_level::LogLevel::*;
-        writeln!($config.log_level().writer_for(&$level), $($expr),+).expect("Can't write output");
+        writeln!($config.log_level().writer_for($level), $($expr),+).expect("Can't write output");
     }}
 }
 
@@ -67,9 +61,9 @@ mod tests {
 
     #[test]
     fn test_is_writable() {
-        assert!(!LogLevel::Quiet.is_writable(&LogLevel::Info));
-        assert!(!LogLevel::Error.is_writable(&LogLevel::Info));
-        assert!(LogLevel::Info.is_writable(&LogLevel::Info));
-        assert!(LogLevel::Info.is_writable(&LogLevel::Error));
+        assert!(!LogLevel::Quiet.is_writable(LogLevel::Info));
+        assert!(!LogLevel::Error.is_writable(LogLevel::Info));
+        assert!(LogLevel::Info.is_writable(LogLevel::Info));
+        assert!(LogLevel::Info.is_writable(LogLevel::Error));
     }
 }
