@@ -1,7 +1,7 @@
 use clap::ValueEnum;
 use std::fmt::Display;
 
-#[derive(Debug, Clone, Default, ValueEnum)]
+#[derive(Debug, Clone, Copy, Default, ValueEnum)]
 pub enum VersionFileStrategy {
     /// Use the local version of Node defined within the current directory
     #[default]
@@ -10,20 +10,17 @@ pub enum VersionFileStrategy {
     Recursive,
 }
 
-impl Display for VersionFileStrategy {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self {
-            VersionFileStrategy::Local => write!(f, "local"),
-            VersionFileStrategy::Recursive => write!(f, "recursive"),
-        }
-    }
-}
-
 impl VersionFileStrategy {
-    pub fn as_str(&self) -> &'static str {
+    pub fn as_str(self) -> &'static str {
         match self {
             VersionFileStrategy::Local => "local",
             VersionFileStrategy::Recursive => "recursive",
         }
     }
 }
+
+impl Display for VersionFileStrategy {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.write_str(self.as_str())
+    }
+}
